BatchOutcomeBuildError

Enum BatchOutcomeBuildError 

pub enum BatchOutcomeBuildError {
    CompletedCountExceeded {
        task_count: usize,
        completed_count: usize,
    },
    FailureCountOverflow {
        failed_count: usize,
        panicked_count: usize,
    },
    TerminalCountOverflow {
        succeeded_count: usize,
        failure_count: usize,
    },
    TerminalCountMismatch {
        completed_count: usize,
        terminal_count: usize,
        succeeded_count: usize,
        failed_count: usize,
        panicked_count: usize,
    },
    FailureDetailCountMismatch {
        expected: usize,
        actual: usize,
    },
    FailureIndexOutOfRange {
        index: usize,
        task_count: usize,
    },
    DuplicateFailureIndex {
        index: usize,
    },
    FailureVariantCountMismatch {
        expected_failed: usize,
        actual_failed: usize,
        expected_panicked: usize,
        actual_panicked: usize,
    },
}
Error returned when constructing a batch outcome with invalid counters.

use qubit_batch::{
    BatchOutcomeBuildError,
    BatchOutcomeBuilder,
};

let error = BatchOutcomeBuilder::<&'static str>::builder(1)
    .completed_count(2)
    .succeeded_count(2)
    .build()
    .expect_err("completed count should not exceed declared task count");

assert!(matches!(
    error,
    BatchOutcomeBuildError::CompletedCountExceeded { .. }
));

Variants



CompletedCountExceeded

The completed task count is greater than the declared task count.

Fields

task_count: usize

Declared task count.

completed_count: usize

Number of completed tasks.



FailureCountOverflow

Adding failed and panicked task counts overflowed.

Fields

failed_count: usize

Number of tasks that returned their own error.

panicked_count: usize

Number of tasks that panicked.



TerminalCountOverflow

Adding successful and failed task counts overflowed.

Fields

succeeded_count: usize

Number of successful tasks.

failure_count: usize

Number of failed or panicked tasks.



TerminalCountMismatch

Completed tasks do not equal successful plus failed plus panicked tasks.

Fields

completed_count: usize

Number of completed tasks.

terminal_count: usize

Number of successful, failed, and panicked tasks combined.

succeeded_count: usize

Number of successful tasks.

failed_count: usize

Number of tasks that returned their own error.

panicked_count: usize

Number of tasks that panicked.



FailureDetailCountMismatch

Detailed failure records do not match the aggregate failure count.

Fields

expected: usize

Expected number of failure details.

actual: usize

Actual number of failure details.



FailureIndexOutOfRange

A failure detail index is outside the declared task range.

Fields

index: usize

Out-of-range failure index.

task_count: usize

Declared task count.



DuplicateFailureIndex

Multiple failure details refer to the same task index.

Fields

index: usize

Duplicate failure index.



FailureVariantCountMismatch

Detailed failure variants do not match failed and panicked counters.

Fields

expected_failed: usize

Expected number of business failure details.

actual_failed: usize

Actual number of business failure details.

expected_panicked: usize

Expected number of panic failure details.

actual_panicked: usize

Actual number of panic failure details.