ParallelBatchExecutorBuilder

Struct ParallelBatchExecutorBuilder 

pub struct ParallelBatchExecutorBuilder { /* private fields */ }
Builder for ParallelBatchExecutor.

Use the builder when the default worker count, sequential fallback threshold, progress interval, or reporter should be customized.

use qubit_batch::ParallelBatchExecutor;

let executor = ParallelBatchExecutor::builder()
    .thread_count(2)
    .sequential_threshold(0)
    .build()
    .expect("parallel executor configuration should be valid");

assert_eq!(executor.thread_count(), 2);
assert_eq!(executor.sequential_threshold(), 0);

Implementations

Source

impl ParallelBatchExecutorBuilder

pub const fn thread_count(self, thread_count: usize) -> Self

Sets the worker-thread count.

Parameters
  • thread_count - Number of scoped worker threads to use.
Returns

This builder for fluent configuration.

pub const fn sequential_threshold(self, sequential_threshold: usize) -> Self

Sets the sequential fallback threshold.

Parameters
  • sequential_threshold - Maximum batch size that still runs sequentially.
Returns

This builder for fluent configuration.

pub const fn report_interval(self, report_interval: Duration) -> Self

Sets the progress-report interval.

Parameters
  • report_interval - Minimum interval between due-based running progress events. Use Duration::ZERO to report at every implementation-defined running progress point.
Returns

This builder for fluent configuration.

pub fn reporter<R>(self, reporter: R) -> Self
where R: ProgressReporter + 'static,

Sets the progress reporter used by built executors.

Parameters
  • reporter - Reporter receiving batch lifecycle callbacks.
Returns

This builder for fluent configuration.

pub fn reporter_arc(self, reporter: Arc<dyn ProgressReporter>) -> Self

Sets the shared progress reporter used by built executors.

Parameters
  • reporter - Shared reporter receiving batch lifecycle callbacks.
Returns

This builder for fluent configuration.

pub fn no_reporter(self) -> Self

Disables progress callbacks by using NoOpProgressReporter.

Returns

This builder for fluent configuration.

pub fn build( self, ) -> Result<ParallelBatchExecutor, ParallelBatchExecutorBuildError>

Builds a validated ParallelBatchExecutor.

Returns

A parallel batch executor when the configuration is valid.

Errors

Returns ParallelBatchExecutorBuildError when the worker count is zero.