SequentialBatchExecutorBuilder

Struct SequentialBatchExecutorBuilder 

pub struct SequentialBatchExecutorBuilder { /* private fields */ }
Builder for SequentialBatchExecutor.

Use the builder when the default progress interval or reporter should be customized.

use std::time::Duration;

use qubit_batch::SequentialBatchExecutor;

let executor = SequentialBatchExecutor::builder()
    .report_interval(Duration::ZERO)
    .build();

assert_eq!(executor.report_interval(), Duration::ZERO);

Implementations

Source

impl SequentialBatchExecutorBuilder

pub const fn report_interval(self, report_interval: Duration) -> Self

Sets the progress-report interval.

Parameters
  • report_interval - Minimum time between due-based running progress callbacks. Duration::ZERO reports at every sequential between-task progress point.
Returns

This builder for fluent configuration.

pub fn reporter<R>(self, reporter: R) -> Self
where R: ProgressReporter + 'static,

Sets the progress reporter used by built executors.

Parameters
  • reporter - Progress reporter used for later executions.
Returns

This builder for fluent configuration.

pub fn reporter_arc(self, reporter: Arc<dyn ProgressReporter>) -> Self

Sets the shared progress reporter used by built executors.

Parameters
  • reporter - Shared progress reporter used for later executions.
Returns

This builder for fluent configuration.

pub fn no_reporter(self) -> Self

Disables progress callbacks by using NoOpProgressReporter.

Returns

This builder for fluent configuration.

pub fn build(self) -> SequentialBatchExecutor

Builds a SequentialBatchExecutor.

Returns

A sequential batch executor with this builder’s configuration.