ChunkedBatchProcessorBuilder

Struct ChunkedBatchProcessorBuilder 

pub struct ChunkedBatchProcessorBuilder<P> { /* private fields */ }
Builder for ChunkedBatchProcessor.

Use the builder when the default progress interval or reporter should be customized.

use std::{
    num::NonZeroUsize,
    time::Duration,
};

use qubit_batch::{
    ChunkedBatchProcessor,
    SequentialBatchProcessor,
};

let delegate = SequentialBatchProcessor::new(|_item: &i32| {});
let processor = ChunkedBatchProcessor::builder(
    delegate,
    NonZeroUsize::new(2).expect("chunk size should be non-zero"),
)
.report_interval(Duration::ZERO)
.build();

assert_eq!(processor.chunk_size().get(), 2);
assert_eq!(processor.report_interval(), Duration::ZERO);

Implementations

Source

impl<P> ChunkedBatchProcessorBuilder<P>

pub fn new(delegate: P, chunk_size: NonZeroUsize) -> Self

Creates a builder from a delegate and chunk size.

Parameters
  • delegate - Processor receiving each chunk.
  • chunk_size - Maximum number of items submitted in one chunk.
Returns

A builder initialized with default chunked processor settings.

pub const fn report_interval(self, report_interval: Duration) -> Self

Sets the progress-report interval.

Parameters
  • report_interval - Minimum time between due-based running progress callbacks. Duration::ZERO reports at every completed-chunk progress point.
Returns

This builder for fluent configuration.

pub fn reporter<R>(self, reporter: R) -> Self
where R: ProgressReporter + 'static,

Sets the progress reporter used by built processors.

Parameters
  • reporter - Progress reporter used for later processing calls.
Returns

This builder for fluent configuration.

pub fn reporter_arc(self, reporter: Arc<dyn ProgressReporter>) -> Self

Sets the shared progress reporter used by built processors.

Parameters
  • reporter - Shared progress reporter used for later processing calls.
Returns

This builder for fluent configuration.

pub fn no_reporter(self) -> Self

Disables progress callbacks by using NoOpProgressReporter.

Returns

This builder for fluent configuration.

pub fn build(self) -> ChunkedBatchProcessor<P>

Builds a ChunkedBatchProcessor.

Returns

A chunked batch processor with this builder’s configuration.