pub enum BatchOutcomeBuildError {
CompletedCountExceeded {
task_count: usize,
completed_count: usize,
},
FailureCountOverflow {
failed_count: usize,
panicked_count: usize,
},
TerminalCountOverflow {
succeeded_count: usize,
failure_count: usize,
},
TerminalCountMismatch {
completed_count: usize,
terminal_count: usize,
succeeded_count: usize,
failed_count: usize,
panicked_count: usize,
},
FailureDetailCountMismatch {
expected: usize,
actual: usize,
},
FailureIndexOutOfRange {
index: usize,
task_count: usize,
},
DuplicateFailureIndex {
index: usize,
},
FailureVariantCountMismatch {
expected_failed: usize,
actual_failed: usize,
expected_panicked: usize,
actual_panicked: usize,
},
}Expand description
Error returned when constructing a batch outcome with invalid counters.
use qubit_batch::{
BatchOutcomeBuildError,
BatchOutcomeBuilder,
};
let error = BatchOutcomeBuilder::<&'static str>::builder(1)
.completed_count(2)
.succeeded_count(2)
.build()
.expect_err("completed count should not exceed declared task count");
assert!(matches!(
error,
BatchOutcomeBuildError::CompletedCountExceeded { .. }
));Variants
CompletedCountExceeded
The completed task count is greater than the declared task count.
FailureCountOverflow
Adding failed and panicked task counts overflowed.
Fields
TerminalCountOverflow
Adding successful and failed task counts overflowed.
Fields
TerminalCountMismatch
Completed tasks do not equal successful plus failed plus panicked tasks.
Fields
FailureDetailCountMismatch
Detailed failure records do not match the aggregate failure count.
Fields
FailureIndexOutOfRange
A failure detail index is outside the declared task range.
DuplicateFailureIndex
Multiple failure details refer to the same task index.
FailureVariantCountMismatch
Detailed failure variants do not match failed and panicked counters.