pub struct BatchExecutionState<E> { /* private fields */ }Expand description
Shared state collected while a batch executor is running.
Implementations
Sourceimpl<E> BatchExecutionState<E>
impl<E> BatchExecutionState<E>
Sourcepub fn record_task_observed(&self) -> usize
pub fn record_task_observed(&self) -> usize
Sourcepub fn record_task_started(&self)
pub fn record_task_started(&self)
Records that one task has started.
Sourcepub fn record_task_succeeded(&self)
pub fn record_task_succeeded(&self)
Records one successful task completion.
Panics
Panics if no active task was recorded for this completion.
Sourcepub fn record_task_failed(&self, index: usize, error: E)
pub fn record_task_failed(&self, index: usize, error: E)
Sourcepub fn record_task_panicked(&self, index: usize, error: BatchTaskError<E>)
pub fn record_task_panicked(&self, index: usize, error: BatchTaskError<E>)
Sourcepub fn progress_counters(&self) -> ProgressCounters
pub fn progress_counters(&self) -> ProgressCounters
Returns generic progress counters for this execution state.
Returns
Counters suitable for progress reporting.
Sourcepub fn into_outcome(self, elapsed: Duration) -> BatchOutcome<E>
pub fn into_outcome(self, elapsed: Duration) -> BatchOutcome<E>