pub struct BatchOutcomeBuilder<E> { /* private fields */ }Expand description
Builder carrying validated parts for a crate::BatchOutcome.
The builder checks aggregate counters, failure detail count, duplicate indexes, and failed-versus-panicked detail counts before creating an outcome.
use qubit_batch::{
BatchOutcomeBuilder,
BatchTaskError,
BatchTaskFailure,
};
let outcome = BatchOutcomeBuilder::builder(2)
.completed_count(2)
.succeeded_count(1)
.failed_count(1)
.failures(vec![BatchTaskFailure::new(
1,
BatchTaskError::Failed("invalid row"),
)])
.build()
.expect("outcome counters should match failure details");
assert_eq!(outcome.failed_count(), 1);
assert_eq!(outcome.failures()[0].index(), 1);Implementations
Sourceimpl<E> BatchOutcomeBuilder<E>
impl<E> BatchOutcomeBuilder<E>
Sourcepub const fn completed_count(self, completed_count: usize) -> Self
pub const fn completed_count(self, completed_count: usize) -> Self
Sourcepub const fn succeeded_count(self, succeeded_count: usize) -> Self
pub const fn succeeded_count(self, succeeded_count: usize) -> Self
Sourcepub const fn failed_count(self, failed_count: usize) -> Self
pub const fn failed_count(self, failed_count: usize) -> Self
Sourcepub const fn panicked_count(self, panicked_count: usize) -> Self
pub const fn panicked_count(self, panicked_count: usize) -> Self
Sourcepub fn failures(self, failures: Vec<BatchTaskFailure<E>>) -> Self
pub fn failures(self, failures: Vec<BatchTaskFailure<E>>) -> Self
Sourcepub fn validate(self) -> Result<Self, BatchOutcomeBuildError>
pub fn validate(self) -> Result<Self, BatchOutcomeBuildError>
Validates this builder and sorts failure records by task index.
Returns
Ok(builder) when the counters and failure details are consistent.
Errors
Returns BatchOutcomeBuildError when the counters or failure details
are inconsistent.
Sourcepub fn build(self) -> Result<BatchOutcome<E>, BatchOutcomeBuildError>
pub fn build(self) -> Result<BatchOutcome<E>, BatchOutcomeBuildError>
Validates this builder and creates a batch outcome.
Returns
Ok(outcome) when the counters and failure details are consistent.
Errors
Returns BatchOutcomeBuildError when the counters or failure details
are inconsistent.