pub struct BatchProcessResultBuilder { /* private fields */ }Expand description
Builder carrying validated parts for a crate::BatchProcessResult.
The builder checks that completed, processed, and chunk counters describe a consistent processing result before creating the result.
use std::time::Duration;
use qubit_batch::BatchProcessResultBuilder;
let result = BatchProcessResultBuilder::builder(3)
.completed_count(3)
.processed_count(3)
.chunk_count(1)
.elapsed(Duration::ZERO)
.build()
.expect("process result counters should be consistent");
assert!(result.is_success());
assert_eq!(result.chunk_count(), 1);Implementations
Sourceimpl BatchProcessResultBuilder
impl BatchProcessResultBuilder
Sourcepub const fn completed_count(self, completed_count: usize) -> Self
pub const fn completed_count(self, completed_count: usize) -> Self
Sourcepub const fn processed_count(self, processed_count: usize) -> Self
pub const fn processed_count(self, processed_count: usize) -> Self
Sourcepub const fn chunk_count(self, chunk_count: usize) -> Self
pub const fn chunk_count(self, chunk_count: usize) -> Self
Sourcepub fn validate(self) -> Result<Self, BatchProcessResultBuildError>
pub fn validate(self) -> Result<Self, BatchProcessResultBuildError>
Validates this builder.
Returns
Ok(builder) when all counters are consistent.
Errors
Returns BatchProcessResultBuildError when the counters are
inconsistent.
Sourcepub fn build(self) -> Result<BatchProcessResult, BatchProcessResultBuildError>
pub fn build(self) -> Result<BatchProcessResult, BatchProcessResultBuildError>
Validates this builder and creates a batch process result.
Returns
Ok(result) when all counters are consistent.
Errors
Returns BatchProcessResultBuildError when the counters are
inconsistent.